@@ -12,6 +12,6 @@ from zoom.apps import App
 app = App()
 app.menu = (
     'Content', 'Fields', 'Collection', 'Components',
-    'Widgets', 'Alerts', 'Flags', 'Parts', 'Tools',
+    'Widgets', 'Charts', 'Alerts', 'Flags', 'Parts', 'Tools',
     'Responses', 'Background', 'About'
 )
