@@ -33,10 +33,11 @@ DEFAULT_SETTINGS = dict(
     in_development=False,
 )
 
+logger = logging.getLogger(__name__)
+
 
 def load_module(module, filename):
     """Dynamically load a module"""
-    logger = logging.getLogger(__name__)
 
     myhandler = \
         ImportError if sys.version_info < (3, 6) else ModuleNotFoundError
@@ -83,8 +84,6 @@ class App(object):
             """test if callable and return it or None"""
             return callable(method) and method
 
-        logger = logging.getLogger(__name__)
-
         isfile = os.path.isfile
         logger.debug('app called with route %r', route)
 
@@ -193,7 +192,6 @@ class AppProxy(object):
         icon = self.config.get('icon')
         is_bootstrap_icon = icon.startswith('bi-')
         if is_bootstrap_icon:
-            zoom.requires('bootstrap-icons')
             return 'bi ' + icon
         return 'fa fa-' + icon
 
@@ -261,7 +259,6 @@ class AppProxy(object):
 
     def run(self, request):
         """run the app"""
-        logger = logging.getLogger(__name__)
         save_dir = os.getcwd()
         try:
             logger.debug('chdir to %r', self.path)
@@ -287,7 +284,6 @@ class AppProxy(object):
             return selector
 
         route = self.site.request.route
-        logger = logging.getLogger(__name__)
         logger.debug('constructing menu')
 
         menu = getattr(self.method, 'menu', [])
@@ -349,7 +345,10 @@ class AppProxy(object):
 
         def get_config(pathname):
             """read a config file"""
-            self.config_parser.read(pathname)
+            try:
+                self.config_parser.read(pathname)
+            except BaseException as e:
+                logger.error('Unable to read %r\n%s', pathname, e)
             return as_dict(self.config_parser)
 
         path = self.path
@@ -491,8 +490,6 @@ def handle(request):
             Database.debug = saved_database_debug_setting
         return result
 
-    logger = logging.getLogger(__name__)
-
     site = request.site
     user = request.user
     if user.is_authenticated:
@@ -751,7 +748,6 @@ def helpers(request):
 
 def handler(request, next_handler, *rest):
     """Dispatch request to an application"""
-    logger = logging.getLogger(__name__)
     logger.debug('apps_handler')
     if '.' not in sys.path:
         logger.debug('adding "." to path')
